summaryrefslogtreecommitdiff
path: root/build.sh
diff options
context:
space:
mode:
authorFrancois-Xavier Le Bail <devel.fx.lebail@orange.fr>2021-02-11 09:25:29 +0100
committerFrancois-Xavier Le Bail <devel.fx.lebail@orange.fr>2021-02-11 10:32:58 +0100
commit40fa95e88afbf944949ee55ccd6b34bb0e7a8f49 (patch)
treeb27f374ccffbc0b3ffa4c4308a808e4e4d232483 /build.sh
parentef1ecde01e69f677cb12650dd4100b0b96d2e411 (diff)
downloadtcpdump-40fa95e88afbf944949ee55ccd6b34bb0e7a8f49.tar.gz
Restore the possibility of building when remote is enabled in libpcap
This change allows to test the build with HAVE_PCAP_FINDALLDEVS_EX and HAVE_PCAP_OPEN enabled. Some ways to run theses tests: MATRIX_BUILD_LIBPCAP=yes MATRIX_REMOTE=yes MATRIX_CMAKE=no MATRIX_CC=gcc \ MATRIX_CRYPTO=no MATRIX_SMB=no ./build_matrix.sh (configure should display: checking for pcap_open... yes checking for pcap_findalldevs_ex... yes) MATRIX_BUILD_LIBPCAP=yes MATRIX_REMOTE=yes MATRIX_CMAKE=yes MATRIX_CC=gcc \ MATRIX_CRYPTO=no MATRIX_SMB=no ./build_matrix.sh (cmake should display: Looking for pcap_open - found Looking for pcap_findalldevs_ex - found) Don't enable the builds with REMOTE=yes by default. This partially reverts commit 3861a41bfa60b9a8bed2d5a11a2ba7a7b1bbed3d. "Remove the REMOTE dimension from the nested matrix."
Diffstat (limited to 'build.sh')
-rwxr-xr-xbuild.sh8
1 files changed, 5 insertions, 3 deletions
diff --git a/build.sh b/build.sh
index a4cf2e93..083559aa 100755
--- a/build.sh
+++ b/build.sh
@@ -1,13 +1,15 @@
#!/usr/bin/env bash
# This script runs one build with setup environment variables: BUILD_LIBPCAP,
# CC, CMAKE, CRYPTO and SMB
# (default: BUILD_LIBPCAP=no, CC=gcc, CMAKE=no, CRYPTO=no, SMB=no).
set -e
# BUILD_LIBPCAP: no or yes
BUILD_LIBPCAP=${BUILD_LIBPCAP:-no}
+# REMOTE: no or yes
+REMOTE=${REMOTE:-no}
# CC: gcc or clang
CC=${CC:-gcc}
# CMAKE: no or yes
@@ -37,7 +39,7 @@ run_after_echo() {
}
# LABEL is needed to build the travis fold labels
-LABEL="$BUILD_LIBPCAP.$CC.$CMAKE.$CRYPTO.$SMB"
+LABEL="$BUILD_LIBPCAP.$REMOTE.$CC.$CMAKE.$CRYPTO.$SMB"
if [ "$CMAKE" = no ]; then
echo '$ ./configure [...]'
travis_fold start configure
@@ -1,13 +1,15 @@
#!/usr/bin/env bash
# This script runs one build with setup environment variables: BUILD_LIBPCAP,
-# CC, CMAKE, CRYPTO and SMB
-# (default: BUILD_LIBPCAP=no, CC=gcc, CMAKE=no, CRYPTO=no, SMB=no).
+# REMOTE, CC, CMAKE, CRYPTO and SMB
+# (default: BUILD_LIBPCAP=no, REMOTE=no, CC=gcc, CMAKE=no, CRYPTO=no, SMB=no).
set -e
# BUILD_LIBPCAP: no or yes